@@ -273,6 +273,10 @@
 #define __PNR_timerfd_settime64			-10239
 #define __PNR_utimensat_time64			-10240
 #define __PNR_ppoll				-10241
+#define __PNR_renameat				-10242
+#define __PNR_riscv_flush_icache		-10243
+#define __PNR_memfd_secret			-10244
+#define __PNR_map_shadow_stack			-10245
 
 /*
  * libseccomp syscall definitions
@@ -398,6 +402,8 @@
 #define __SNR_cacheflush		__PNR_cacheflush
 #endif
 
+#define __SNR_cachestat			__NR_cachestat
+
 #define __SNR_capget			__NR_capget
 
 #define __SNR_capset			__NR_capset
@@ -474,6 +480,8 @@
 
 #define __SNR_close			__NR_close
 
+#define __SNR_close_range		__NR_close_range
+
 #ifdef __NR_connect
 #define __SNR_connect			__NR_connect
 #else
@@ -532,6 +540,8 @@
 
 #define __SNR_epoll_pwait		__NR_epoll_pwait
 
+#define __SNR_epoll_pwait2		__NR_epoll_pwait2
+
 #ifdef __NR_epoll_wait
 #define __SNR_epoll_wait		__NR_epoll_wait
 #else
@@ -562,6 +572,8 @@
 
 #define __SNR_faccessat			__NR_faccessat
 
+#define __SNR_faccessat2		__NR_faccessat2
+
 #ifdef __NR_fadvise64
 #define __SNR_fadvise64			__NR_fadvise64
 #else
@@ -586,6 +598,8 @@
 
 #define __SNR_fchmodat			__NR_fchmodat
 
+#define __SNR_fchmodat2			__NR_fchmodat2
+
 #ifdef __NR_fchown
 #define __SNR_fchown			__NR_fchown
 #else
@@ -708,12 +722,20 @@
 
 #define __SNR_futex			__NR_futex
 
+#define __SNR_futex_requeue		__NR_futex_requeue
+
 #ifdef __NR_futex_time64
 #define __SNR_futex_time64		__NR_futex_time64
 #else
 #define __SNR_futex_time64		__PNR_futex_time64
 #endif
 
+#define __SNR_futex_wait		__NR_futex_wait
+
+#define __SNR_futex_waitv		__NR_futex_waitv
+
+#define __SNR_futex_wake		__NR_futex_wake
+
 #ifdef __NR_futimesat
 #define __SNR_futimesat			__NR_futimesat
 #else
@@ -1000,6 +1022,10 @@
 
 #define __SNR_kill			__NR_kill
 
+#define __SNR_landlock_add_rule		__NR_landlock_add_rule
+#define __SNR_landlock_create_ruleset	__NR_landlock_create_ruleset
+#define __SNR_landlock_restrict_self	__NR_landlock_restrict_self
+
 #ifdef __NR_lchown
 #define __SNR_lchown			__NR_lchown
 #else
@@ -1060,6 +1086,12 @@
 
 #define __SNR_madvise			__NR_madvise
 
+#ifdef __NR_map_shadow_stack
+#define __SNR_map_shadow_stack		__NR_map_shadow_stack
+#else
+#define __SNR_map_shadow_stack		__PNR_map_shadow_stack
+#endif
+
 #ifdef __NR_mbind
 #define __SNR_mbind			__NR_mbind
 #else
@@ -1078,6 +1110,12 @@
 #define __SNR_memfd_create		__PNR_memfd_create
 #endif
 
+#ifdef __NR_memfd_secret
+#define __SNR_memfd_secret		__NR_memfd_secret
+#else
+#define __SNR_memfd_secret		__PNR_memfd_secret
+#endif
+
 #ifdef __NR_migrate_pages
 #define __SNR_migrate_pages		__NR_migrate_pages
 #else
@@ -1128,6 +1166,8 @@
 
 #define __SNR_mount			__NR_mount
 
+#define __SNR_mount_setattr		__NR_mount_setattr
+
 #ifdef __NR_move_mount
 #define __SNR_move_mount		__NR_move_mount
 #else
@@ -1264,12 +1304,6 @@
 #define __SNR_olduname			__PNR_olduname
 #endif
 
-#ifdef __NR_oldwait4
-#define __SNR_oldwait4			__NR_oldwait4
-#else
-#define __SNR_oldwait4			__PNR_oldwait4
-#endif
-
 #ifdef __NR_open
 #define __SNR_open			__NR_open
 #else
@@ -1286,6 +1320,8 @@
 
 #define __SNR_openat			__NR_openat
 
+#define __SNR_openat2			__NR_openat2
+
 #ifdef __NR_pause
 #define __SNR_pause			__NR_pause
 #else
@@ -1314,6 +1350,8 @@
 
 #define __SNR_personality		__NR_personality
 
+#define __SNR_pidfd_getfd		__NR_pidfd_getfd
+
 #ifdef __NR_pidfd_open
 #define __SNR_pidfd_open		__NR_pidfd_open
 #else
@@ -1382,6 +1420,10 @@
 
 #define __SNR_prlimit64			__NR_prlimit64
 
+#define __SNR_process_madvise		__NR_process_madvise
+
+#define __SNR_process_mrelease		__NR_process_mrelease
+
 #define __SNR_process_vm_readv		__NR_process_vm_readv
 
 #define __SNR_process_vm_writev		__NR_process_vm_writev
@@ -1428,6 +1470,8 @@
 
 #define __SNR_quotactl			__NR_quotactl
 
+#define __SNR_quotactl_fd		__NR_quotactl_fd
+
 #ifdef __NR_read
 #define __SNR_read			__NR_read
 #else
@@ -1494,7 +1538,11 @@
 #define __SNR_rename			__PNR_rename
 #endif
 
+#ifdef __NR_renameat
 #define __SNR_renameat			__NR_renameat
+#else
+#define __SNR_renameat			__PNR_renameat
+#endif
 
 #define __SNR_renameat2			__NR_renameat2
 
@@ -1502,6 +1550,12 @@
 
 #define __SNR_restart_syscall		__NR_restart_syscall
 
+#ifdef __NR_riscv_flush_icache
+#define __SNR_riscv_flush_icache	__NR_riscv_flush_icache
+#else
+#define __SNR_riscv_flush_icache	__PNR_riscv_flush_icache
+#endif
+
 #ifdef __NR_rmdir
 #define __SNR_rmdir			__NR_rmdir
 #else
@@ -1688,6 +1742,8 @@
 #define __SNR_set_mempolicy		__PNR_set_mempolicy
 #endif
 
+#define __SNR_set_mempolicy_home_node	__NR_set_mempolicy_home_node
+
 #define __SNR_set_robust_list		__NR_set_robust_list
 
 #ifdef __NR_set_thread_area
